q1ss.utils.options
==================

.. automodule:: q1ss.utils.options

Q1SSOptions
-----------

.. autoclass:: q1ss.utils.options.Q1SSOptions
    :show-inheritance:
    :members:
    :special-members: __call__, __getitem__, __setitem__

options
-------

.. autodata:: q1ss.utils.options.options
